@@ -42,7 +42,7 @@ class fMMS_ConfigDialog():
 		apnHBox.pack_start(apn_label, False, True, 0)
 		apnHBox.pack_start(apn_button, True, True, 0)
 
-		numberHBox = gtk.HBox()
+		"""numberHBox = gtk.HBox()
 		number_label = gtk.Label("Your phonenumber")
 		number_label.set_width_chars(labelwidth)
 		number_label.set_alignment(0, 0.5)
@@ -54,7 +54,7 @@ class fMMS_ConfigDialog():
 		else:
 			self.number.set_text("")
 		numberHBox.pack_start(number_label, False, True, 0)
-		numberHBox.pack_start(self.number, True, True, 0)
+		numberHBox.pack_start(self.number, True, True, 0)"""
 
 		imgwidthHBox = gtk.HBox()
 		imgwidth_label = gtk.Label("Resize image width")
@@ -104,7 +104,7 @@ class fMMS_ConfigDialog():
 		expHBox.pack_start(alignment, False, True, 0)
 
 		allVBox.pack_start(apnHBox, False, False, 2)
-		allVBox.pack_start(numberHBox, False, False, 2)
+		#allVBox.pack_start(numberHBox, False, False, 2)
 		allVBox.pack_start(imgwidthHBox, False, False, 2)
 		allVBox.pack_end(expHBox, False, False, 2)
 
@@ -179,7 +179,7 @@ class fMMS_ConfigDialog():
 	def config_menu_button_clicked(self, action):
 		""" Checks if we should save the Configuration options. """
 		if action == gtk.RESPONSE_APPLY:
-			self.config.set_phonenumber(self.number.get_text())
+			#self.config.set_phonenumber(self.number.get_text())
 			selectorlabel = self.imgwidth.get_selector().get_current_text()
 			size = 0
 			for (label, val) in self.imgmodes:
@@ -203,13 +203,16 @@ class APNConfigDialog():
 		self.config = fMMSconf.fMMS_config()
 		self.cont = fMMSController.fMMS_controller()
 		
+		pan = hildon.PannableArea()
+		pan.set_property("mov-mode", hildon.MOVEMENT_MODE_VERT)
+		
+		
 		allVBox = gtk.VBox()
 		
 		labelwidth = 16
 
-		inputs = [('Access point name', 'apn'), ('Username', 'user'),
-			  ('Password', 'pass'), ('Proxy', 'proxy'), ('Proxy Port', 'proxyport'),
-			  ('MMSC', 'mmsc')]
+		inputs = [('Access point name', 'apn'), ('MMSC', 'mmsc'), ('Username', 'user'),
+			  ('Password', 'pass'), ('Proxy', 'proxy'), ('Proxy Port', 'proxyport')]
 		
 		entries = {}
 		
@@ -233,7 +236,8 @@ class APNConfigDialog():
 			label = gtk.Label(labelname)
 			label.set_width_chars(labelwidth)
 			label.set_alignment(0, 0.5)
-			vars()[var] = gtk.Entry()
+			#vars()[var] = gtk.Entry()
+			vars()[var] = hildon.Entry(gtk.HILDON_SIZE_FINGER_HEIGHT)
 			if var == "proxyport":
 				vars()[var].set_property('hildon-input-mode', gtk.HILDON_GTK_INPUT_MODE_NUMERIC)
 			if current:
@@ -244,20 +248,11 @@ class APNConfigDialog():
 			box.pack_start(vars()[var], True, True, 0)
 			allVBox.pack_start(box, False, False, 2)
 
-		box = gtk.HBox()
-		label = gtk.Label("In 99/100 cases you don't need to change anything in advanced.")
-		#label.set_width_chars(labelwidth)
-		label.set_line_wrap(True)
-		button = hildon.Button(gtk.HILDON_SIZE_FINGER_HEIGHT, hildon.BUTTON_ARRANGEMENT_HORIZONTAL)
-		button.set_label("Advanced")
-		button.connect('clicked', self.create_advanced_config, dialog)
-		box.pack_start(label, True, True, 0)
-		box.pack_start(button, True, True, 0)
-		
-		allVBox.pack_end(box, False, False, 2)
-
-		allVBox.show_all()
-		dialog.vbox.add(allVBox)
+		pan.add_with_viewport(allVBox)
+		pan.set_size_request_policy(hildon.SIZE_REQUEST_CHILDREN)
+		dialog.vbox.add(pan)
+		dialog.show_all()
+		dialog.add_button("Advanced", 999)
 		dialog.add_button("Save", gtk.RESPONSE_APPLY)
 		
 		while 1:
@@ -266,6 +261,8 @@ class APNConfigDialog():
 			for val in entries:
 				settings[val] = vars()[val].get_text()
 
+			if ret == 999:
+				self.create_advanced_config(dialog)
 			if ret == gtk.RESPONSE_APPLY:
 				# We can hardcode the checks here since
 				# the fields have to exist here
@@ -275,6 +272,7 @@ class APNConfigDialog():
 					banner = hildon.hildon_banner_show_information(parent, "", "Invalid MMSC.")
 				else:
 					settings['proxy'] = self.cont.convert_to_real_ip(settings['proxy'])
+					settings['mmsc'] = self.cont.clean_url(settings['mmsc'])
 					self.config.set_apn_settings(settings)
 					log.info("Set APN settings: %s" % settings)
 					banner = hildon.hildon_banner_show_information(parent, "", "APN settings saved")
@@ -284,7 +282,7 @@ class APNConfigDialog():
 		
 		dialog.destroy()
 		
-	def create_advanced_config(self, widget, spawnedby):
+	def create_advanced_config(self, spawnedby):
 		dialog = gtk.Dialog()
 		dialog.set_title("Advanced Configuration")
 
@@ -314,7 +312,8 @@ class APNConfigDialog():
 			label = gtk.Label(labelname)
 			label.set_width_chars(labelwidth)
 			label.set_alignment(0, 0.5)
-			vars()[var] = gtk.Entry()
+			#vars()[var] = gtk.Entry()
+			vars()[var] = hildon.Entry(gtk.HILDON_SIZE_FINGER_HEIGHT)
 			if current:
 				if current.get(var, None):
 					vars()[var].set_text(str(current[var]))
