@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2.5
 # -*- coding: utf-8 -*-
 """ Class for handling wap push messages and creating MMS messages
 
@@ -8,7 +8,7 @@ Copyright (C) 2010 Nick Leppänen Larsson <frals@frals.se>
 @license: GNU GPLv2, see COPYING file.
 """
 import os
-import dbus
+import sys
 import urllib2
 import httplib
 import time
@@ -17,25 +17,19 @@ import array
 import subprocess
 
 import dbus
-import conic
+import pynotify
 
 from mms import message
 from mms.message import MMSMessage
 from mms import mms_pdu
 import fmms_config as fMMSconf
 import controller as fMMSController
+import contacts as ContactH
+import connectors
 
 import logging
 log = logging.getLogger('fmms.%s' % __name__)
 
-magic = 0xacdcacdc
-
-CONNMODE_UGLYHACK = 1
-CONNMODE_ICDSWITCH = 2
-CONNMODE_FORCESWITCH = 3
-CONNMODE_NULL = 10
-
-_DBG = True
 
 class PushHandler:
 	def __init__(self):
@@ -49,10 +43,9 @@ class PushHandler:
 
 	def _incoming_sms_push(self, source, src_port, dst_port, wsp_header, wsp_payload):
 		""" handle incoming push over sms """
-		#dbus_loop = DBusGMainLoop()
+		log.info("Incoming SMS Push!")
 		args = (source, src_port, dst_port, wsp_header, wsp_payload)
 		
-		# TODO: dont hardcode
 		if not os.path.isdir(self.config.get_imgdir()):
 			os.makedirs(self.config.get_imgdir())
 		
@@ -62,11 +55,8 @@ class PushHandler:
 		    f.write('\n')
 		f.close()
 
-		if(_DBG):
-			log.info("SRC: %s:%s", source, src_port)
-			log.info("DST: %s", dst_port)
-			#print "WSPHEADER: ", wsp_header
-			#print "WSPPAYLOAD: ", wsp_payload
+		log.info("SRC: %s:%s", source, src_port)
+		log.info("DST: %s", dst_port)
 
 		binarydata = []
 		# throw away the wsp_header!
@@ -80,6 +70,10 @@ class PushHandler:
 		
 		(data, sndr, url, trans_id) = self.cont.decode_mms_from_push(binarydata)
 		
+		
+		ch = ContactH.ContactHandler()
+		sndr = ch.get_displayname_from_number(sndr)
+		
 		log.info("saving...")
 		# Controller should save it
 		pushid = self.cont.save_push_message(data)
@@ -89,36 +83,46 @@ class PushHandler:
 		except:
 			log.info("failed to fetch - notifying push...")
 			# Send a notify we got the SMS Push and parsed it A_OKEY!
-			self.notify_mms(sndr, "SMS Push for MMS received")
+			try:
+				self.notify_mms(sndr, "SMS Push for MMS received")
+			except:
+				log.exception("hej")
+			log.info("notified...")
 			raise
 		log.info("decoding mms... path: %s", path)
 		message = self.cont.decode_binary_mms(path)
 		log.info("storing mms...")
 		self.cont.store_mms_message(pushid, message, transactionId=trans_id)
 		log.info("notifying mms...")
-		self.notify_mms(sndr, "New MMS", trans_id);
+		self.notify_mms(sndr, "New MMS", trans_id)
+		log.info("done, returning!")
 		return 0
 
 	# TODO: implement this
 	def _incoming_ip_push(self, src_ip, dst_ip, src_port, dst_port, wsp_header, wsp_payload):
 		""" handle incoming ip push """
-		if(_DBG):
-			log.info("SRC: %s:%s", src_ip, src_port)
-			log.info("DST: %s:%s", dst_ip, dst_port)
+		log.info("SRC: %s:%s", src_ip, src_port)
+		log.info("DST: %s:%s", dst_ip, dst_port)
 
 	def notify_mms(self, sender, msg, path=None):
 		""" notifies the user with a org.freedesktop.Notifications.Notify, really fancy """
-		bus = dbus.SystemBus()
-		proxy = bus.get_object('org.freedesktop.Notifications', '/org/freedesktop/Notifications')
-		interface = dbus.Interface(proxy, dbus_interface='org.freedesktop.Notifications')
-		choices = ['default', 'cancel']
-		if path == None:
-			interface.Notify('MMS', 0, '', msg, sender, choices, {"category": "sms-message", "dialog-type": 4, "led-pattern": "PatternCommunicationEmail", "dbus-callback-default": "se.frals.fmms /se/frals/fmms se.frals.fmms open_gui"}, -1)
+		pynotify.init("fMMS")
+		note = pynotify.Notification(sender, msg, "fmms")
+		note.set_urgency(pynotify.URGENCY_CRITICAL)
+		note.set_hint("led-pattern", "PatternCommunicationEmail")
+		if path:
+			note.set_hint("dbus-callback-default", "se.frals.fmms /se/frals/fmms se.frals.fmms open_mms string:\"" + path + "\"")
 		else:
-			interface.Notify("MMS", 0, '', msg, sender, choices, {"category": "email-message", "dialog-type": 4, "led-pattern": "PatternCommunicationEmail", "dbus-callback-default": "se.frals.fmms /se/frals/fmms se.frals.fmms open_mms string:\"" + path + "\""}, -1)
+			note.set_hint("dbus-callback-default", "se.frals.fmms /se/frals/fmms se.frals.fmms open_gui")
+		# we have to fake being an email for vibra/sound... oh well!
+		bus = dbus.SessionBus()
+		proxy = bus.get_object('com.nokia.HildonSVNotificationDaemon', '/com/nokia/HildonSVNotificationDaemon')
+		interface = dbus.Interface(proxy,dbus_interface='com.nokia.HildonSVNotificationDaemon')
+		interface.PlayEvent({'time': 0, 'category': 'email-message'}, "fmms")
+		note.show()
 
 	def _get_mms_message(self, location, transaction):
-		connector = MasterConnector()
+		connector = connectors.MasterConnector()
 		connector.connect(location)
 				
 		try:
@@ -235,7 +239,7 @@ class MMSSender:
 			self._sender = sender
 			self.createMMS()
 			if self.setupConn == True:
-				self.connector = MasterConnector()
+				self.connector = connectors.MasterConnector()
 				self.connector.connect()
 				
 	    
@@ -337,193 +341,15 @@ class MMSSender:
 		return res.status, res.reason, outparsed, parsed
 
 
-class MasterConnector:
-	""" handles setting up and (might) take down connection(s) """
-
-	def __init__(self):
-		self.cont = fMMSController.fMMS_controller()
-		self.config = fMMSconf.fMMS_config()
-		self._apn = self.config.get_apn()
-		self._apn_nicename = self.config.get_apn_nicename()
-	
-	def connect(self, location="0"):
-		if (self.config.get_connmode() == CONNMODE_UGLYHACK):
-			log.info("RUNNING IN UGLYHACK MODE")
-
-			(proxyurl, proxyport) = self.config.get_proxy_from_apn()
-			apn = self.config.get_apn_from_osso()
-			mmsc1 = self.cont.get_host_from_url(self.config.get_mmsc())
-			mmsc2 = self.cont.get_host_from_url(location)
-			user = self.config.get_user_for_apn()
-			passwd = self.config.get_passwd_for_apn()
-			try:
-				self.connector = UglyHackHandler(apn, user, passwd, proxyurl, mmsc1, mmsc2)
-				self.connector.start()
-			except:
-				log.exception("Connection failed.")
-
-		elif (self.config.get_connmode() == CONNMODE_ICDSWITCH):
-			log.info("RUNNING IN ICDSWITCH MODE")
-			self.connector = ICDConnector(self._apn)
-			self.connector.connect()
-			# TODO: dont sleep this long unless we have to
-			time.sleep(15)
-
-		elif (self.config.get_connmode() == CONNMODE_FORCESWITCH):
-			log.info("RUNNING IN FORCESWITCH MODE")
-			self.connector = ForceConnector(self._apn)
-			self.connector.connect()
-			# TODO: dont sleep this long unless we have to
-			time.sleep(15)
-		
-		elif (self.config.get_connmode() == CONNMODE_NULL):
-			log.info("NOOP CONNMODE")
-			self.connector = None
-	
-	def disconnect(self):
-		try:
-			if self.connector:
-				self.connector.disconnect()
-		except:
-			log.exception("Failed to close connection.")
-
-
-class ICDConnector:
-	""" this is the 'nice' autoconnecter, only goes online on
-	the mms apn if no other conn is active """
-
-	def __init__(self, apn):
-		self.apn = apn
-		self.connection = conic.Connection()
-		
-	def connection_cb(self, connection, event, mgc):
-		#log.info("connection_cb(%s, %s, %x)" % (connection, event, mgc))
-		pass	
-		
-	def disconnect(self):
-		connection = self.connection
-                connection.disconnect_by_id(self.apn)
-		log.info("ICDConnector requested disconnect from id: %s", self.apn)
-
-	def connect(self):
-		global magic
-
-		# Creates the connection object and attach the handler.
-		connection = self.connection
-		iaps = connection.get_all_iaps()
-		iap = None
-		for i in iaps:
-			if i.get_id() == self.apn:
-				iap = i
-		
-		if iap:
-			connection.disconnect()
-			log.info("ICDConnector trying to connect to ID: %s", iap.get_id())
-		connection.connect("connection-event", self.connection_cb, magic)
-		if iap:
-			connection.request_connection_by_id(iap.get_id(), conic.CONNECT_FLAG_NONE)
-		else:
-			connection.request_connection(conic.CONNECT_FLAG_NONE)
-		
-
-class ForceConnector:
-	""" this is the 'force switch' autoconnecter """
-	# credits to Stuart Hopkins for implementing this as
-	# a shell script and submitting as a patch
-	
-	def __init__(self, apn):
-		self.apn = apn
-		self.current_connection()
-		self.connection = conic.Connection()
-		
-	def current_connection(self):
-		bus = dbus.SystemBus()
-		proxy = bus.get_object('com.nokia.icd', '/com/nokia/icd')
-		icd = dbus.Interface(proxy, 'com.nokia.icd')
-		try:
-			(iapid, arg, arg1, arg2, arg3, arg4, arg5) = icd.get_statistics()
-		except:
-			iapid = None
-		self.previousconn = iapid
-		log.info("ForceConnector saved previous connection. ID: %s", iapid)
-		
-	def connection_cb(self, connection, event, mgc):
-		#log.info("connection_cb(%s, %s, %x)" % (connection, event, mgc))
+if __name__ == '__main__':
+	source = sys.argv[1]
+	srcport = sys.argv[2]
+	dstport = sys.argv[3]
+	header = sys.argv[4]
+	payload = sys.argv[5]
+	push = PushHandler()
+	print source, srcport, dstport, header, payload
+	try:
+		push._incoming_sms_push(source, srcport, dstport, eval(header), eval(payload))
+	except:
 		pass
-		
-	""" restore connection to previous """
-	def disconnect(self):
-		log.info("ForceConnector restoring connection...")
-		self.connect(self.previousconn)
-	
-	""" actually disconnects from the current iap before connecting """
-	def connect(self, apn=None):
-		global magic
-		
-		args = "DISCONNECT"
-		subprocess.call(["/opt/fmms/fmms_magic", args])
-		log.info("ForceConnector disconnecting from active connection.")
-
-		if apn == None:
-			apn = self.apn
-	
-		# Creates the connection object and attach the handler.
-		connection = self.connection
-		iaps = connection.get_all_iaps()
-		iap = None
-		for i in iaps:
-			if i.get_id() == apn:
-				iap = i
-		
-		if iap:		
-			log.info("ForceConnector trying to connect to: ID: %s" % iap.get_id())
-		connection.connect("connection-event", self.connection_cb, magic)
-		
-		if iap:
-			connection.request_connection_by_id(iap.get_id(), conic.CONNECT_FLAG_NONE)
-		else:
-			connection.request_connection(conic.CONNECT_FLAG_NONE)
-
-
-class UglyHackHandler:
-	""" the ugly-hack autoconnector """
-	
-	def __init__(self, apn, username="", password="", proxy="0", mmsc1="0", mmsc2="0"):
-		self.apn = apn
-		self.username = username
-		self.password = password
-		if proxy == None:
-			proxy = 0
-		self.proxyip = proxy
-		self.mmsc1 = mmsc1
-		self.mmsc2 = mmsc2
-		self.rx = 0
-		self.tx = 0
-		log.info("UglyHackHandler UP!\nAPN: %s user: %s pass: %s proxyip: %s mmsc1: %s mmsc2: %s" % (self.apn, self.username, self.password, self.proxyip, self.mmsc1, self.mmsc2))
-		self.conn = self.connect()
-
-	def start(self):
-		args = "START %s %s %s %s %s %s" % (self.iface, self.ipaddr, self.mmsc1, self.mmsc2, self.dnsip, self.proxyip)
-		retcode = subprocess.call(["/opt/fmms/fmms_magic", args])
-		log.info("fmms_magic retcode: %s" % retcode)
-		
-	def connect(self):
-		bus = dbus.SystemBus()
-		gprs = dbus.Interface(bus.get_object("com.nokia.csd", "/com/nokia/csd/gprs"), "com.nokia.csd.GPRS")
-		obj = gprs.QuickConnect(self.apn, "IP", self.username, self.password)
-		conn = dbus.Interface(bus.get_object("com.nokia.csd", obj), "com.nokia.csd.GPRS.Context")
-		(apn, ctype, self.iface, self.ipaddr, connected, tx, rx) = conn.GetStatus()
-		
-		tmp = bus.get_object("com.nokia.csd.GPRS", obj)
-		props = dbus.Interface(tmp, "org.freedesktop.DBus.Properties")
-		self.dnsip = props.Get("com.nokia.csd.GPRS.Context", "PDNSAddress")
-		
-		return conn
-		
-	def disconnect(self):
-		log.info("UglyHackHandler running disconnect")
-		(apn, ctype, self.iface, self.ipaddr, connected, self.tx, self.rx) = self.conn.GetStatus()
-		args = "STOP %s" % self.iface
-		retcode = subprocess.call(["/opt/fmms/fmms_magic", args])
-		log.info("disconnecting connection. rx: %s tx: %s" % (self.rx, self.tx))
-		self.conn.Disconnect()
\ No newline at end of file
